// 商品相关
import { request } from "@/lib/service"

/**
 * @desc 商品+店铺集合+店铺搜索接口
 * @param { Object } params so many key, see the api docs
 *  {
		page 当前页码
		pagenum 每页条数
		sort 排序：1综合优先 2销量优先 3价格升序 4价格降序
		keywords 关键字
	}
 */
export function searchGoods(params) {
	return request({
		url: 'zsxcx/searchGoodsXcx.htm',
		method: 'post',
		data: params,
		needMask: true
	})
}


/**
 * @desc 商品详情
 * @param { goods_id } 商品ID
 */
export function goodDetail(goods_id) {
	return request({
		url: 'zsxcx/goodsDetail.htm',
		method: 'post',
		data: {
			goods_id
		}
	})
}

/**
 * @desc 商品规格选择接口
 * goods_id
 */
export function goodsSku(goods_id) {
	return request({
		url: 'zsxcx/goodsSku.htm',
		method: 'post',
		data: {
			goods_id
		}
	})
}

/**
 * @desc 商品详情页tab动态显示判断接口
 * goods_id
 */
// export function goodsDetailTab(goods_id) {
// 	return request({
// 		url: 'zsxcx/getTabShow.htm',
// 		method: 'post',
// 		data: {
// 			goods_id
// 		}
// 	})
// }

/**
 * @desc 商品收藏列表
 * @param { Number } page 当前页码
 * @param { Number } pagenum 条数
 */
export function collectGoodsList(params) {
	return request({
		url: 'zsxcx/collection.htm',
		method: 'post',
		needMask: true,
		data: params
	})
}

/**
 * @desc 收藏/取消收藏
 */
export function collectGoods(goods_id) {
	return request({
		url: 'zsxcx/collectGoods.htm',
		method: 'post',
		data: {
			goods_id
		}, 
		needMask: true
	})
}
