import { isFunction, isObeject } from "@/utils/types.js"
import Toast from "@/lib/toast/index.js"
import store from "@/store/index.js"
/**
 * @desc 倒计时
 * @param { Number } num 倒计时时间
 * @param { Functiom } cb 回调 
 */
export function timerFn(num = 60, cb) {
	let timer = setInterval(() => {
		cb && isFunction(cb) && cb(num)
		num --
		if(num < 0) {
			clearInterval(timer)
			timer = null
			return
		}
	}, 1000)
}

/**
 * @desc 节流函数 cv的
 * @param {Function} callback 回调函数
 * @param {Number} wait 间隔时间
 * @return {Function} 节流函数
 */
export function throttle(callback, wait = 3000) {
    let timer = null;
    let startTime;
    return function () {
        const ctx = this;
        const args = arguments;
        const now = +new Date();
        if (startTime && now < startTime + wait) {
            clearTimeout(timer);
            timer = setTimeout(function () {
                startTime = now;
                callback.apply(ctx, args);
            }, wait);
        } else {
            startTime = now;
            callback.apply(ctx, args);
        }
    }
}

/**
 * @desc 防抖函数  cv的
 * @param {需要防抖的函数} func
 * @param {延迟时间} wait
 * @param {是否立即执行} immediate
 */
export function debounce(func, wait = 1000, immediate = true) {
  let timeout
  return function(...args) {
    let context = this
    if (timeout) clearTimeout(timeout)

    if (immediate) {
      let callNow = !timeout
      timeout = setTimeout(function() {
        timeout = null
      }, wait)
      if (callNow) func.apply(context, args)
    } else {
      timeout = setTimeout(function() {
        func.apply(context, args)
      }, wait)
    }
  }
}

/**
 * 联系老板 
 */
export function makePhoneCall() {
	const storeInfo = store.state.user.storeInfo
	if(storeInfo && storeInfo.shop_tel) {
		const phoneNumber = storeInfo.shop_tel
		uni.showModal({
			content: `是否拨打${phoneNumber}`,
			success: res => {
				if(res.confirm) {
					uni.makePhoneCall({
						phoneNumber
					})
				} 
			}
		})
	}
}

export function getURLwithArgs(){
	const pages = getCurrentPages()
	const currentPage = pages[pages.length-1]
	const url = currentPage.route
	const options = currentPage.options
	//拼接url的参数
	let urlWithArgs = `${url}?`
	for(let key in options){
		const value = options[key]
		urlWithArgs += `${key}=${value}&`
	}
	urlWithArgs = urlWithArgs.substring(0, urlWithArgs.length-1)
	return urlWithArgs
}

/**
 * @desc 微信接口promise
 * @param { String } wxapi *
 * @param { Object  } ops 接口的配置
 * @param { Object } cops 自定义的配置   
 */
export function cWx(wxapi, ops = {}, cops = {}) {
	if(!isObeject(ops) || !isObeject(cops)) throw new Error('配置必须是对象')
	if(cops.loading) {
		wx.showLoading({
			mask: true
		})
	}
	return new Promise((resolve, reject) => {
		wx[wxapi]({
			...ops,
			success: res => {
				cops.scb && typeof cops.scb === 'function' && cops.scb()
				resolve({status: true, data: res, msg: 'success'})
			},
			fail: err => {
				cops.fcb && typeof cops.fcb === 'function' && cops.fcb()
				reject({status: true, data: null, msg: err})
			},
			complete: () => {
				cops.ccb && typeof cops.ccb === 'function' && cops.ccb()
				if(cops.loading) {
					wx.hideLoading()
				}
			}
		})
	})
}